@@ -140,6 +140,30 @@ soup_message_headers_clear (SoupMessageHeaders *hdrs)
 	clear_special_headers (hdrs);
 }
 
+/**
+ * soup_message_headers_clean_connection_headers:
+ * @hdrs: a #SoupMessageHeaders
+ *
+ * Removes all the headers listed in the Connection header.
+ *
+ **/
+void
+soup_message_headers_clean_connection_headers (SoupMessageHeaders *hdrs)
+{
+	/* RFC 2616 14.10 */
+	const char *connection;
+	GSList *tokens, *t;
+
+	connection = soup_message_headers_get_list (hdrs, "Connection");
+	if (!connection)
+		return;
+
+	tokens = soup_header_parse_list (connection);
+	for (t = tokens; t; t = t->next)
+		soup_message_headers_remove (hdrs, t->data);
+	soup_header_free_list (tokens);
+}
+
 /**
  * soup_message_headers_append:
  * @hdrs: a #SoupMessageHeaders
@@ -468,7 +492,7 @@ soup_message_headers_iter_next (SoupMessageHeadersIter *iter,
 /**
  * soup_message_headers_foreach:
  * @hdrs: a #SoupMessageHeaders
- * @func: callback function to run for each header
+ * @func: (scope call): callback function to run for each header
  * @user_data: data to pass to @func
  * 
  * Calls @func once for each header value in @hdrs.
@@ -1187,7 +1211,7 @@ content_type_setter (SoupMessageHeaders *hdrs, const char *value)
 /**
  * soup_message_headers_get_content_type:
  * @hdrs: a #SoupMessageHeaders
- * @params: return location for the Content-Type parameters (eg,
+ * @params: (out) (allow-none): return location for the Content-Type parameters (eg,
  * "charset"), or %NULL
  *
  * Looks up the "Content-Type" header in @hdrs, parses it, and returns
